<?php
/**
 * AmaTheme functions and definitions.
 *
 * Sets up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development
 * and http://codex.wordpress.org/Child_Themes), you can override certain
 * functions (those wrapped in a function_exists() call) by defining them first
 * in your child theme's functions.php file. The child theme's functions.php
 * file is included before the parent theme's file, so the child theme
 * functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * see http://codex.wordpress.org/Plugin_API
 *
 * @package WordPress
 * @subpackage AmaTheme
 * @since AmaTheme 1.0
 */

/**
 * Sets up the content width value based on the theme's design.
 * @see amatheme_content_width() for template-specific adjustments.
 */
if ( ! isset( $content_width ) )
	$content_width = 604;

/**
 * Adds support for a custom header image.

require get_template_directory() . '/inc/custom-header.php'; */

/**
 * Adds support to install Advanced Custom Fields
 */
require_once dirname( __FILE__ ) . '/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'my_theme_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function my_theme_register_required_plugins() {
 
    /**
     * Array of plugin arrays. Required keys are name, slug and required.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(
  
        // This is an example of how to include a plugin from the WordPress Plugin Repository
        array(
            'name'      => 'Advanced Custom Fields',
            'slug'      => 'advanced-custom-fields',
            'required'  => true,
			'force_activation'      => true, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
            'force_deactivation'    => true, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
        ),
 
    );
 
    // Change this to your theme text domain, used for internationalising strings
    $theme_text_domain = 'amatheme';
 
    /**
     * Array of configuration settings. Amend each line as needed.
     * If you want the default strings to be available under your own theme domain,
     * leave the strings uncommented.
     * Some of the strings are added into a sprintf, so see the comments at the
     * end of each line for what each argument will be.
     */
    $config = array(
        'domain'            => $theme_text_domain,           // Text domain - likely want to be the same as your theme.
        // 'default_path'      => '',                           // Default absolute path to pre-packaged plugins
        // 'parent_menu_slug'  => 'themes.php',         // Default parent menu slug
        // 'parent_url_slug'   => 'themes.php',         // Default parent URL slug
        'menu'              => 'install-required-plugins',   // Menu slug
        'has_notices'       => true,                         // Show admin notices or not
        'is_automatic'      => true,            // Automatically activate plugins after installation or not
        'message'           => '',               // Message to output right before the plugins table
        'strings'           => array(
            'page_title'                                => __( 'Install Required Plugins', $theme_text_domain ),
            'menu_title'                                => __( 'Install Plugins', $theme_text_domain ),
            'installing'                                => __( 'Installing Plugin: %s', $theme_text_domain ), // %1$s = plugin name
            'oops'                                      => __( 'Something went wrong with the plugin API.', $theme_text_domain ),
            'notice_can_install_required'               => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.' ), // %1$s = plugin name(s)
            'notice_can_install_recommended'            => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.' ), // %1$s = plugin name(s)
            'notice_cannot_install'                     => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.' ), // %1$s = plugin name(s)
            'notice_can_activate_required'              => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s)
            'notice_can_activate_recommended'           => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s)
            'notice_cannot_activate'                    => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.' ), // %1$s = plugin name(s)
            'notice_ask_to_update'                      => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.' ), // %1$s = plugin name(s)
            'notice_cannot_update'                      => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.' ), // %1$s = plugin name(s)
            'install_link'                              => _n_noop( 'Begin installing plugin', 'Begin installing plugins' ),
            'activate_link'                             => _n_noop( 'Activate installed plugin', 'Activate installed plugins' ),
            'return'                                    => __( 'Return to Required Plugins Installer', $theme_text_domain ),
            'plugin_activated'                          => __( 'Plugin activated successfully.', $theme_text_domain ),
            'complete'                                  => __( 'All plugins installed and activated successfully. %s', $theme_text_domain ) // %1$s = dashboard link
        )
    );
 
    tgmpa( $plugins, $config );
 
}

// Custom excerpt length
	function custom_excerpt_length($length) {
		return 14;
	}
	add_filter('excerpt_length', 'custom_excerpt_length');

/**
 * AmaTheme only works in WordPress 3.6 or later.
 */
if ( version_compare( $GLOBALS['wp_version'], '3.6-alpha', '<' ) )
	require get_template_directory() . '/inc/back-compat.php';

/**
 * Sets up theme defaults and registers the various WordPress features that
 * AmaTheme supports.
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_editor_style() To add Visual Editor stylesheets.
 * @uses add_theme_support() To add support for automatic feed links, post
 * formats, and post thumbnails.
 * @uses register_nav_menu() To add support for a navigation menu.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since AmaTheme 1.0
 *
 * @return void
 */
function amatheme_setup() {
	/*
	 * Makes AmaTheme available for translation.
	 *
	 * Translations can be added to the /languages/ directory.
	 * If you're building a theme based on AmaTheme, use a find and
	 * replace to change 'amatheme' to the name of your theme in all
	 * template files.
	 */
	load_theme_textdomain( 'amatheme', get_template_directory() . '/languages' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', 'fonts/genericons.css', amatheme_fonts_url() ) );

	// Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	// Switches default core markup for search form, comment form, and comments
	// to output valid HTML5.
	add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list' ) );

	/*
	 * This theme supports all available post formats by default.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'audio', 'gallery', 'image', 'link', 'quote', 'status', 'video'
	) );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Navigation Menu', 'amatheme' ) );

	/*
	 * This theme uses a custom image size for featured images, displayed on
	 * "standard" posts and pages.
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 604, 270, true );
	
	add_image_size('featured', 800, 500, true );
	add_image_size('reviewed', 250, 140, true );

	// This theme uses its own gallery styles.
	add_filter( 'use_default_gallery_style', '__return_false' );
}
add_action( 'after_setup_theme', 'amatheme_setup' );

/**
 * Returns the Google font stylesheet URL, if available.
 *
 * The use of Source Sans Pro and Bitter by default is localized. For languages
 * that use characters not supported by the font, the font can be disabled.
 *
 * @since AmaTheme 1.0
 *
 * @return string Font stylesheet or empty string if disabled.
 */
function amatheme_fonts_url() {
	$fonts_url = '';

	/* Translators: If there are characters in your language that are not
	 * supported by Source Sans Pro, translate this to 'off'. Do not translate
	 * into your own language.
	 */
	$source_sans_pro = _x( 'on', 'Source Sans Pro font: on or off', 'amatheme' );

	/* Translators: If there are characters in your language that are not
	 * supported by Bitter, translate this to 'off'. Do not translate into your
	 * own language.
	 */
	$bitter = _x( 'on', 'Bitter font: on or off', 'amatheme' );

	if ( 'off' !== $source_sans_pro || 'off' !== $bitter ) {
		$font_families = array();

		if ( 'off' !== $source_sans_pro )
			$font_families[] = 'Source Sans Pro:300,400,700,300italic,400italic,700italic';

		if ( 'off' !== $bitter )
			$font_families[] = 'Bitter:400,700';

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);
		$fonts_url = add_query_arg( $query_args, "//fonts.googleapis.com/css" );
	}

	return $fonts_url;
}

/**
 * Enqueues scripts and styles for front end.
 *
 * @since AmaTheme 1.0
 *
 * @return void
 */
function amatheme_scripts_styles() {
	// Adds JavaScript to pages with the comment form to support sites with
	// threaded comments (when in use).
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	// Adds Masonry to handle vertical alignment of footer widgets.
	if ( is_active_sidebar( 'sidebar-1' ) )
		wp_enqueue_script( 'jquery-masonry' );

	// Loads JavaScript file with functionality specific to AmaTheme.
	wp_enqueue_script( 'amatheme-script', get_template_directory_uri() . '/js/functions.js', array( 'jquery' ), '2013-07-18', true );
	wp_enqueue_script( 'amatheme-bootscript', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), null, true );
	wp_enqueue_script( 'amatheme-fitvid', get_template_directory_uri() . '/js/fitvid.js', array( 'jquery' ), null, true );

	// Add Open Sans and Bitter fonts, used in the main stylesheet.
	wp_enqueue_style( 'amatheme-fonts', amatheme_fonts_url(), array(), null );

	// Add Genericons font, used in the main stylesheet.
	wp_enqueue_style( 'genericons', get_template_directory_uri() . '/fonts/genericons.css', array(), '2.09' );

	// Loads our main stylesheet.
	wp_enqueue_style( 'amatheme-bootstrap', get_template_directory_uri() . '/css/bootstrap.css', array() );
	wp_enqueue_style( 'amatheme-style', get_stylesheet_uri(), array(), '2013-07-18' );
	wp_enqueue_style( 'amatheme-fontawesome', get_template_directory_uri() . '/css/font-awesome.min.css', array() );
	wp_enqueue_style( 'amatheme-fontawesomeie', get_template_directory_uri() . '/css/font-awesome-ie7.min.css', array() );
	

	// Loads the Internet Explorer specific stylesheet.
	wp_enqueue_style( 'amatheme-ie', get_template_directory_uri() . '/css/ie.css', array( 'amatheme-style' ), '2013-07-18' );
	wp_style_add_data( 'amatheme-ie', 'conditional', 'lt IE 9' );
}
add_action( 'wp_enqueue_scripts', 'amatheme_scripts_styles' );

/**
 * Creates a nicely formatted and more specific title element text for output
 * in head of document, based on current view.
 *
 * @since AmaTheme 1.0
 *
 * @param string $title Default title text for current view.
 * @param string $sep Optional separator.
 * @return string The filtered title.
 */
function amatheme_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() )
		return $title;

	// Add the site name.
	$title .= get_bloginfo( 'name' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";

	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'amatheme' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'amatheme_wp_title', 10, 2 );

/**
 * Registers widget areas.
 *
 * @since AmaTheme 1.0
 *
 * @return void
 */
function amatheme_widgets_init() {
	
	register_sidebar( array(
		'name'          => __( 'Leaderboard', 'amatheme' ),
		'id'            => 'leaderboard',
		'description'   => __( '728x90 Leaderboard ad (do not use titles)', 'amatheme' ),
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '',
		'after_title'   => '',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar Widget Area', 'amatheme' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Appears on posts and pages in the sidebar.', 'amatheme' ),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget'  => '</li>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget One', 'amatheme' ),
		'id'            => 'footer-1',
		'description'   => __( 'First footer widget area', 'amatheme' ),
		'before_widget' => '<div id="%1$s" class="widget col-xs-4 col-lg-4 %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget Two', 'amatheme' ),
		'id'            => 'footer-2',
		'description'   => __( 'Second footer widget area', 'amatheme' ),
		'before_widget' => '<div id="%1$s" class="widget col-xs-6 col-lg-6 %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget Three', 'amatheme' ),
		'id'            => 'footer-3',
		'description'   => __( 'Third footer widget area', 'amatheme' ),
		'before_widget' => '<div id="%1$s" class="widget col-xs-2 col-lg-2 %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Menu', 'amatheme' ),
		'id'            => 'footermenu',
		'description'   => __( 'Footer menu area (do not use titles)', 'amatheme' ),
		'before_widget' => '<div id="%1$s" class="widget col-md-12 %2$s"',
		'after_widget'  => '</div>',
		'before_title'  => '',
		'after_title'   => '',
	) );
	
}
add_action( 'widgets_init', 'amatheme_widgets_init' );


// Register custom navigation walker
require_once('wp_bootstrap_navwalker.php');


// Post Type
	
	add_action( 'init', 'create_post_type' );
	function create_post_type() {
		register_post_type( 'comparison',
			array(
				'labels' => array(
					'name' => __( 'Comparisons', 'amatheme' ),
					'singular_name' => __( 'Comparison', 'amatheme' ),
					'add_new' => _x('Add New Comparison', 'portfolio item', 'amatheme'),
					'add_new_item' => __('New Product Comparison', 'amatheme'),
					'edit_item' => __('Edit Product Comparison', 'amatheme'),
					'new_item' => __('New Product Comparison', 'amatheme'),
					'view_item' => __('View Product Comparison', 'amatheme'),
					'search_items' => __('Search Comparisons', 'amatheme'),
					'not_found' =>  __('Nothing found', 'amatheme'),
					'not_found_in_trash' => __('Nothing found in Trash', 'amatheme'),
				),
				'public' => true,
				'has_archive' => true,
				'publicly_queryable' => true,
				'show_ui' => true,
				'query_var' => true,
				'rewrite' => array('slug' => 'compare'),
				'capability_type' => 'post',
				'supports' => array('title','editor','thumbnail','comments','excerpt'),
				'taxonomies' => array( 'category ')
			)
		);
	}
	
	register_taxonomy("comparisons", array("comparison"), array("hierarchical" => true, "label" => "Comparison Category", "singular_label" => "Category: ", "rewrite" => true));


// Logo upload
function amatheme_theme_customizer( $wp_customize ) {

    // Logo upload
    $wp_customize->add_section( 'amatheme_logo_section' , array(
         'title' => __( 'Logo', 'debut' ),
         'description' => 'Upload a logo to replace the default site name and description in the header',
        ) );
	
	$wp_customize->add_section( 'amatheme_homepage_section' , array(
         'title' => __( 'Home Page', 'debut' ),
         'description' => 'Customize your home page',
        ) );
		
	$wp_customize->add_setting( 'amatheme_logo' );
	$wp_customize->add_setting( 'amatheme_homepage', array( 'default' => 0,	) );
	$wp_customize->add_setting( 'amatheme_homepagereviews', array( 'default' => 0,	) );
	$wp_customize->add_setting( 'amatheme_homepageblogposts', array( 'default' => 0,	) );
    
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'amatheme_logo', array(
                'label' => __( 'Logo', 'debut' ),
                'section' => 'amatheme_logo_section',
                'settings' => 'amatheme_logo',
        ) ) );
	 
	$wp_customize->add_control( 'amatheme_homepage', array(
		'label' => 'Hide the "Compare & Buy" section',
		'type' => 'checkbox',
		'section' => 'amatheme_homepage_section',
         'settings' => 'amatheme_homepage',
	) );
	
	$wp_customize->add_control( 'amatheme_homepagereviews', array(
		'label' => 'Hide the "Recently Reviewed" section',
		'type' => 'checkbox',
		'section' => 'amatheme_homepage_section',
         'settings' => 'amatheme_homepagereviews',
	) );
	
	$wp_customize->add_control( 'amatheme_homepageblogposts', array(
		'label' => 'Hide the "Recent Blog Posts" section',
		'type' => 'checkbox',
		'section' => 'amatheme_homepage_section',
         'settings' => 'amatheme_homepageblogposts',
	) );
		
	$wp_customize->add_setting(
        'amatheme_link_color',
        array(
            'default'     => '#F97B13',
			'transport'   => 'postMessage'
			)
		);
		
	$wp_customize->add_setting(
        'amatheme_link_hover_color',
        array(
            'default'     => '#13B4F9',
			'transport'   => 'postMessage'
			)
		);
		
	$wp_customize->add_setting(
        'amatheme_navbg_color',
        array(
            'default'     => '#428bca',
			'transport'   => 'postMessage'
			)
		);
		
	$wp_customize->add_setting(
        'amatheme_navbghover_color',
        array(
            'default'     => '#3276B1',
			'transport'   => 'postMessage'
			)
		);
		
	$wp_customize->add_setting(
        'amatheme_navbglink_color',
        array(
            'default'     => '#ffffff',
			'transport'   => 'postMessage'
			)
		);
		
	$wp_customize->add_setting(
        'amatheme_srfrbg_color',
        array(
            'default'     => '#fafafa',
			'transport'   => 'postMessage'
			)
		);
 
    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'link_color',
            array(
                'label'      => __( 'Link Color', 'amatheme' ),
                'section'    => 'colors',
                'settings'   => 'amatheme_link_color'
				)
		)
	);
	
	$wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'link_hover_color',
            array(
                'label'      => __( 'Link Hover Color (live preview not shown)', 'amatheme' ),
                'section'    => 'colors',
                'settings'   => 'amatheme_link_hover_color'
            )
		)
	);
	
	$wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'navbg_color',
            array(
                'label'      => __( 'Nav Background', 'amatheme' ),
                'section'    => 'colors',
                'settings'   => 'amatheme_navbg_color'
            )
		)
	);
	
	$wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'navbghover_color',
            array(
                'label'      => __( 'Nav Background Hover', 'amatheme' ),
                'section'    => 'colors',
                'settings'   => 'amatheme_navbghover_color'
            )
		)
	);
	
	$wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'navbglink_color',
            array(
                'label'      => __( 'Navigation Links (overwrites Link Color)', 'amatheme' ),
                'section'    => 'colors',
                'settings'   => 'amatheme_navbglink_color'
            )
		)
	);
	
	$wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'srfrbg_color',
            array(
                'label'      => __( 'Sidebar + Footer Background', 'amatheme' ),
                'section'    => 'colors',
                'settings'   => 'amatheme_srfrbg_color'
            )
		)
	);
	

}
add_action('customize_register', 'amatheme_theme_customizer');

function amatheme_customizer_css() {
    ?>
    <style type="text/css">
        a { color: <?php echo get_theme_mod( 'amatheme_link_color' ); ?>; }
		a:hover { color: <?php echo get_theme_mod( 'amatheme_link_hover_color' ); ?>; }
		.navbar-teal { background-color: <?php echo get_theme_mod( 'amatheme_navbg_color' ); ?>; }
		.navbar-teal .nav > li > a { color: <?php echo get_theme_mod( 'amatheme_navbglink_color' ); ?>; }
		.navbar-teal .dropdown-menu li a { color: <?php echo get_theme_mod( 'amatheme_navbghover_color' ); ?>; }
		.navbar-teal .nav li.dropdown > .dropdown-toggle .caret { border-top-color: <?php echo get_theme_mod( 'amatheme_navbglink_color' ); ?>; }
		.nav .open a, .nav > li > a:hover, .nav .open a:hover, .nav .open a:focus, .nav > li > a:focus, .navbar-teal .nav li.dropdown.open > .dropdown-toggle, .navbar-teal .nav li.dropdown.active > .dropdown-toggle, .navbar-teal .nav li.dropdown.open.active > .dropdown-toggle, .navbar-teal .dropdown-menu li > a:hover, .navbar-teal .dropdown-menu li > a:focus, .navbar-teal .dropdown-submenu:hover > a { background: <?php echo get_theme_mod( 'amatheme_navbghover_color' ); ?>; }
		#sidebar .well, footer { background: <?php echo get_theme_mod( 'amatheme_srfrbg_color' ); ?>; }
    </style>
    <?php
}
add_action( 'wp_head', 'amatheme_customizer_css' );

	
/* Function courtesy wefunction.com - For Image */
	$meta_boxes =
		array(
			"azonrating" => array(
				  "name" => "azonrating",
				  "type" => "text",
				  "std" => "",
				  "title" => "Star rating",
				  "description" => "Give a rating to your reviewed product, available ratings: <code>.5</code> <code>1</code> <code>1.5</code> <code>2</code>, <code>2.5</code> <code>3</code> <code>3.5</code> <code>4</code> <code>4.5</code> <code>5</code>"),
			"azonafflink" => array(
				  "name" => "azonafflink",
				  "type" => "text",
				  "std" => "",
				  "title" => "Buy Now Affiliate Link",
				  "description" => "Enter your affiliate link above. Example: <code>http://www.amazon.com/tag=YourAffiliateLink-20</code>")
		);

	function meta_boxes() {
		global $post, $meta_boxes;
		echo'<style type="text/css">#inactive-plugins-table td { border-bottom: 1px solid #eee; padding: 10px; } #inactive-plugins-table input{margin: 0 0 10px !important;}{</style>
			<table cellspacing="0" id="inactive-plugins-table">
				<tbody class="plugins">';
				foreach($meta_boxes as $meta_box) {
					$meta_box_value = get_post_meta($post->ID, $pre.'_value', true);

					if($meta_box_value == "")
						$meta_box_value = $meta_box['std'];
					echo'<tr>
							<td valign="top">';		
								echo'<input type="hidden" name="'.$meta_box['name'].'_noncename" id="'.$meta_box['name'].'_noncename" value="'.wp_create_nonce( plugin_basename(__FILE__) ).'" />';
								echo'<h2 style="font-weight: normal; font-size: 14px; margin: 0;">'.$meta_box['title'].'</h2>';
					echo'	</td>
							<td>';
						  switch ($meta_box['type']) {
							 case "text":
								  echo'<input type="text" name="'.$meta_box['name'].'_value" value="'.get_post_meta($post->ID, $meta_box['name'].'_value', true).'" style="border-color: #999;  margin-left: 10px; width: 90%;" /><br />';
								break;
							 case "textarea":
									echo'<textarea name="'.$meta_box['name'].'_value" style="border-color: #999; width: 50%; height: 100px; margin-left: 10px;">'.get_post_meta($post->ID, $meta_box['name'].'_value', true).'</textarea><br />';			     
								break;
						  }
								echo'<p><label for="'.$meta_box['name'].'_value">'.$meta_box['description'].'</p>';
					echo'	</td>
						</tr>';
				}
		echo'
		</tbody>
		</table>';
	}

	function create_meta_box() {
		global $theme_name;
		if ( function_exists('add_meta_box') ) {
			add_meta_box( 'new-meta-boxes', 'Affiliate Area', 'meta_boxes', 'post', 'normal', 'high' );
		}
	}

	function save_postdata( $post_id ) {
		global $post, $meta_boxes;

		foreach($meta_boxes as $meta_box) {
			// Verify
			if ( !wp_verify_nonce( $_POST[$meta_box['name'].'_noncename'], plugin_basename(__FILE__) )) {
				return $post_id;
			}
		
			if ( 'page' == $_POST['post_type'] ) {
				if ( !current_user_can( 'edit_page', $post_id ))
					return $post_id;
			} else {
				if ( !current_user_can( 'edit_post', $post_id ))
					return $post_id;
			}
		
			$data = $_POST[$meta_box['name'].'_value'];
			
			if(get_post_meta($post_id, $meta_box['name'].'_value') == "")
				add_post_meta($post_id, $meta_box['name'].'_value', $data, true);
			elseif($data != get_post_meta($post_id, $pre.'_value', true))
				update_post_meta($post_id, $meta_box['name'].'_value', $data);
			elseif($data == "")
				delete_post_meta($post_id, $meta_box['name'].'_value', get_post_meta($post_id, $meta_box['name'].'_value', true));
		}
	}

	add_action('admin_menu', 'create_meta_box');
	add_action('save_post', 'save_postdata');
	
	
// ACF fields


/**
 *  Install Add-ons
 *  
 *  The following code will include all 4 premium Add-Ons in your theme.
 *  Please do not attempt to include a file which does not exist. This will produce an error.
 *  
 *  The following code assumes you have a folder 'add-ons' inside your theme.
 *
 *  IMPORTANT
 *  Add-ons may be included in a premium theme/plugin as outlined in the terms and conditions.
 *  For more information, please read:
 *  - http://www.advancedcustomfields.com/terms-conditions/
 *  - http://www.advancedcustomfields.com/resources/getting-started/including-lite-mode-in-a-plugin-theme/
 */ 

// Add-ons 
// include_once('add-ons/acf-repeater/acf-repeater.php');
// include_once('add-ons/acf-gallery/acf-gallery.php');
// include_once('add-ons/acf-flexible-content/acf-flexible-content.php');
// include_once( 'add-ons/acf-options-page/acf-options-page.php' );


/**
 *  Register Field Groups
 *
 *  The register_field_group function accepts 1 array which holds the relevant data to register a field group
 *  You may edit the array as you see fit. However, this may result in errors if the array is not compatible with ACF
 */

if(function_exists("register_field_group"))
{
	register_field_group(array (
		'id' => 'acf_comparisons',
		'title' => 'Comparisons',
		'fields' => array (
			array (
				'key' => 'field_525fbf12aca21',
				'label' => 'Comparison 1',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_5262ce4668f1d',
				'label' => 'Title',
				'name' => 'title_1',
				'type' => 'text',
				'default_value' => '',
				'placeholder' => 'Enter product title here',
				'prepend' => '',
				'append' => '',
				'formatting' => 'none',
				'maxlength' => '',
			),
			array (
				'key' => 'field_525f8855a94dd',
				'label' => 'Content',
				'name' => 'compare_1',
				'type' => 'wysiwyg',
				'default_value' => '',
				'toolbar' => 'full',
				'media_upload' => 'no',
			),
			array (
				'key' => 'field_525f8add544d6',
				'label' => 'Affiliate Link',
				'name' => 'affiliate_link_1',
				'type' => 'text',
				'instructions' => 'Example: http://www.amazon.com/tablets/tag=YourAffiliateLink-20',
				'default_value' => '',
				'placeholder' => 'place the products affiliate link here',
				'prepend' => '',
				'append' => '',
				'formatting' => 'none',
				'maxlength' => '',
			),
			array (
				'key' => 'field_525fb87ca3837',
				'label' => 'Featured Image',
				'name' => 'compare_1_image',
				'type' => 'image',
				'save_format' => 'id',
				'preview_size' => 'thumbnail',
				'library' => 'all',
			),
			array (
				'key' => 'field_525fc41f67dbb',
				'label' => 'Rating',
				'name' => 'rating_1',
				'type' => 'select',
				'choices' => array (
					5 => 5,
					'4.5' => '4.5',
					4 => 4,
					'3.5' => '3.5',
					3 => 3,
					'2.5' => '2.5',
					2 => 2,
					'1.5' => '1.5',
					1 => 1,
					'.5' => '.5',
				),
				'default_value' => '',
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_525fbfc0e9b2e',
				'label' => 'Comparison 2',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_5262ce7d68f1e',
				'label' => 'Title',
				'name' => 'title_2',
				'type' => 'text',
				'default_value' => '',
				'placeholder' => 'Enter product title here',
				'prepend' => '',
				'append' => '',
				'formatting' => 'none',
				'maxlength' => '',
			),
			array (
				'key' => 'field_525f88aba94de',
				'label' => 'Content',
				'name' => 'compare_2',
				'type' => 'wysiwyg',
				'default_value' => '',
				'toolbar' => 'full',
				'media_upload' => 'no',
			),
			array (
				'key' => 'field_525fb50fa3834',
				'label' => 'Affiliate Link',
				'name' => 'affiliate_link_2',
				'type' => 'text',
				'instructions' => 'Example: http://www.amazon.com/tablets/tag=YourAffiliateLink-20',
				'default_value' => '',
				'placeholder' => 'place the products affiliate link here',
				'prepend' => '',
				'append' => '',
				'formatting' => 'none',
				'maxlength' => '',
			),
			array (
				'key' => 'field_525fb8b9a3838',
				'label' => 'Featured Image',
				'name' => 'compare_2_image',
				'type' => 'image',
				'save_format' => 'id',
				'preview_size' => 'thumbnail',
				'library' => 'all',
			),
			array (
				'key' => 'field_525fc550207c6',
				'label' => 'Rating',
				'name' => 'rating_2',
				'type' => 'select',
				'choices' => array (
					5 => 5,
					'4.5' => '4.5',
					4 => 4,
					'3.5' => '3.5',
					3 => 3,
					'2.5' => '2.5',
					2 => 2,
					'1.5' => '1.5',
					1 => 1,
					'.5' => '.5',
				),
				'default_value' => '',
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_525fbfeee9b2f',
				'label' => 'Comparison 3',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_5262ce8868f1f',
				'label' => 'Title',
				'name' => 'title_3',
				'type' => 'text',
				'default_value' => '',
				'placeholder' => 'Enter product title here',
				'prepend' => '',
				'append' => '',
				'formatting' => 'none',
				'maxlength' => '',
			),
			array (
				'key' => 'field_525f88d3a94e0',
				'label' => 'Content',
				'name' => 'compare_3',
				'type' => 'wysiwyg',
				'default_value' => '',
				'toolbar' => 'full',
				'media_upload' => 'no',
			),
			array (
				'key' => 'field_525fb847a3835',
				'label' => 'Affiliate Link',
				'name' => 'affiliate_link_3',
				'type' => 'text',
				'instructions' => 'Example: http://www.amazon.com/tablets/tag=YourAffiliateLink-20',
				'default_value' => '',
				'placeholder' => 'place the products affiliate link here',
				'prepend' => '',
				'append' => '',
				'formatting' => 'none',
				'maxlength' => '',
			),
			array (
				'key' => 'field_525fbe37fa10a',
				'label' => 'Featured Image',
				'name' => 'compare_3_image',
				'type' => 'image',
				'save_format' => 'id',
				'preview_size' => 'thumbnail',
				'library' => 'all',
			),
			array (
				'key' => 'field_525fc550207c5',
				'label' => 'Rating',
				'name' => 'rating_3',
				'type' => 'select',
				'choices' => array (
					5 => 5,
					'4.5' => '4.5',
					4 => 4,
					'3.5' => '3.5',
					3 => 3,
					'2.5' => '2.5',
					2 => 2,
					'1.5' => '1.5',
					1 => 1,
					'.5' => '.5',
				),
				'default_value' => '',
				'allow_null' => 0,
				'multiple' => 0,
			),
			array (
				'key' => 'field_525fbff3e9b30',
				'label' => 'Comparison 4',
				'name' => '',
				'type' => 'tab',
			),
			array (
				'key' => 'field_5262ce9068f20',
				'label' => 'Title',
				'name' => 'title_4',
				'type' => 'text',
				'default_value' => '',
				'placeholder' => 'Enter product title here',
				'prepend' => '',
				'append' => '',
				'formatting' => 'none',
				'maxlength' => '',
			),
			array (
				'key' => 'field_525f88e8a94e1',
				'label' => 'Content',
				'name' => 'compare_4',
				'type' => 'wysiwyg',
				'default_value' => '',
				'toolbar' => 'full',
				'media_upload' => 'no',
			),
			array (
				'key' => 'field_525fb863a3836',
				'label' => 'Affiliate Link',
				'name' => 'affiliate_link_4',
				'type' => 'text',
				'instructions' => 'Example: http://www.amazon.com/tablets/tag=YourAffiliateLink-20',
				'default_value' => '',
				'placeholder' => 'place the products affiliate link here',
				'prepend' => '',
				'append' => '',
				'formatting' => 'none',
				'maxlength' => '',
			),
			array (
				'key' => 'field_525fbe4efa10b',
				'label' => 'Featured Image',
				'name' => 'compare_4_image',
				'type' => 'image',
				'save_format' => 'id',
				'preview_size' => 'thumbnail',
				'library' => 'all',
			),
			array (
				'key' => 'field_525fc54d207c4',
				'label' => 'Rating',
				'name' => 'rating_4',
				'type' => 'select',
				'choices' => array (
					5 => 5,
					'4.5' => '4.5',
					4 => 4,
					'3.5' => '3.5',
					3 => 3,
					'2.5' => '2.5',
					2 => 2,
					'1.5' => '1.5',
					1 => 1,
					'.5' => '.5',
				),
				'default_value' => '',
				'allow_null' => 0,
				'multiple' => 0,
			),
		),
		'location' => array (
			array (
				array (
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'comparison',
					'order_no' => 0,
					'group_no' => 0,
				),
			),
		),
		'options' => array (
			'position' => 'normal',
			'layout' => 'default',
			'hide_on_screen' => array (
				0 => 'excerpt',
				1 => 'revisions',
				2 => 'format',
			),
		),
		'menu_order' => 0,
	));
}



// ACF fields ends
	
	
	
if ( ! function_exists( 'amatheme_paging_nav' ) ) :
/**
 * Displays navigation to next/previous set of posts when applicable.
 *
 * @since AmaTheme 1.0
 *
 * @return void
 */
function amatheme_paging_nav() {
	global $wp_query;

	// Don't print empty markup if there's only one page.
	if ( $wp_query->max_num_pages < 2 )
		return;
	?>
	<nav class="navigation paging-navigation" role="navigation">
		<h3 class="screen-reader-text"><?php _e( 'Posts navigation', 'amatheme' ); ?></h3>
		<div class="nav-links">

			<?php if ( get_next_posts_link() ) : ?>
			<div class="nav-previous pull-left"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'amatheme' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="nav-next pull-right"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'amatheme' ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'amatheme_post_nav' ) ) :
/**
 * Displays navigation to next/previous post when applicable.
*
* @since AmaTheme 1.0
*
* @return void
*/
function amatheme_post_nav() {
	global $post;

	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous )
		return;
	?>
	<nav class="navigation post-navigation" role="navigation">
		<h3 class="screen-reader-text"><?php _e( 'Other Posts', 'amatheme' ); ?></h3>
		<div class="nav-links">

			<?php previous_post_link( '<span class="pull-left">%link</span>', _x( '<span class="meta-nav">&larr;</span> %title', 'Previous post link', 'amatheme' ) ); ?>
			<?php next_post_link( '<span class="pull-right">%link</span>', _x( '%title <span class="meta-nav">&rarr;</span>', 'Next post link', 'amatheme' ) ); ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'amatheme_entry_meta' ) ) :
/**
 * Prints HTML with meta information for current post: categories, tags, permalink, author, and date.
 *
 * Create your own amatheme_entry_meta() to override in a child theme.
 *
 * @since AmaTheme 1.0
 *
 * @return void
 */
function amatheme_entry_meta() {
	if ( is_sticky() && is_home() && ! is_paged() )
		echo '<span class="post-meta-element featured-post">' . __( 'Sticky', 'amatheme' ) . '</span>';

	if ( ! has_post_format( 'link' ) && 'post' == get_post_type() )
		amatheme_entry_date();

	// Translators: used between list items, there is a space after the comma.
	$categories_list = get_the_category_list( __( ', ', 'amatheme' ) );
	if ( $categories_list ) {
		echo '<span class="post-meta-element categories-links"><span class="glyphicon glyphicon-folder-open" style="padding-right: 7px;"></span>' . $categories_list . '</span>';
	}

	// Translators: used between list items, there is a space after the comma.
	$tag_list = get_the_tag_list( '', __( ', ', 'amatheme' ) );
	if ( $tag_list ) {
		echo '<span class="post-meta-element tags-links"><span class="glyphicon glyphicon-tag"></span> ' . $tag_list . '</span>';
	}

}
endif;

if ( ! function_exists( 'amatheme_entry_date' ) ) :
/**
 * Prints HTML with date information for current post.
 *
 * Create your own amatheme_entry_date() to override in a child theme.
 *
 * @since AmaTheme 1.0
 *
 * @param boolean $echo Whether to echo the date. Default true.
 * @return string The HTML-formatted post date.
 */
function amatheme_entry_date( $echo = true ) {
	if ( has_post_format( array( 'chat', 'status' ) ) )
		$format_prefix = _x( '%1$s on %2$s', '1: post format name. 2: date', 'amatheme' );
	else
		$format_prefix = '%2$s';

	$date = sprintf( '<span class="date"><span class="glyphicon glyphicon-calendar"></span> <time class="entry-date" datetime="%3$s">%4$s</time></span>',
		esc_url( get_permalink() ),
		esc_attr( sprintf( __( 'Permalink to %s', 'amatheme' ), the_title_attribute( 'echo=0' ) ) ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( sprintf( $format_prefix, get_post_format_string( get_post_format() ), get_the_date() ) )
	);

	if ( $echo )
		echo $date;

	return $date;
}
endif;

if ( ! function_exists( 'amatheme_the_attached_image' ) ) :
/**
 * Prints the attached image with a link to the next attached image.
 *
 * @since AmaTheme 1.0
 *
 * @return void
 */
function amatheme_the_attached_image() {
	$post                = get_post();
	$attachment_size     = apply_filters( 'amatheme_attachment_size', array( 800, 500 ) );
	$next_attachment_url = wp_get_attachment_url();

	/**
	 * Grab the IDs of all the image attachments in a gallery so we can get the URL
	 * of the next adjacent image in a gallery, or the first image (if we're
	 * looking at the last image in a gallery), or, in a gallery of one, just the
	 * link to that image file.
	 */
	$attachment_ids = get_posts( array(
		'post_parent'    => $post->post_parent,
		'fields'         => 'ids',
		'numberposts'    => -1,
		'post_status'    => 'inherit',
		'post_type'      => 'attachment',
		'post_mime_type' => 'image',
		'order'          => 'ASC',
		'orderby'        => 'menu_order ID'
	) );

	// If there is more than 1 attachment in a gallery...
	if ( count( $attachment_ids ) > 1 ) {
		foreach ( $attachment_ids as $attachment_id ) {
			if ( $attachment_id == $post->ID ) {
				$next_id = current( $attachment_ids );
				break;
			}
		}

		// get the URL of the next image attachment...
		if ( $next_id )
			$next_attachment_url = get_attachment_link( $next_id );

		// or get the URL of the first image attachment.
		else
			$next_attachment_url = get_attachment_link( array_shift( $attachment_ids ) );
	}

	printf( '<a href="%1$s" title="%2$s" rel="attachment" class="thumbnail">%3$s</a>',
		esc_url( $next_attachment_url ),
		the_title_attribute( array( 'echo' => false ) ),
		wp_get_attachment_image( $post->ID, $attachment_size )
	);
}
endif;

/**
 * Returns the URL from the post.
 *
 * @uses get_url_in_content() to get the URL in the post meta (if it exists) or
 * the first link found in the post content.
 *
 * Falls back to the post permalink if no URL is found in the post.
 *
 * @since AmaTheme 1.0
 *
 * @return string The Link format URL.
 */
function amatheme_get_link_url() {
	$content = get_the_content();
	$has_url = get_url_in_content( $content );

	return ( $has_url ) ? $has_url : apply_filters( 'the_permalink', get_permalink() );
}

/**
 * Extends the default WordPress body classes.
 *
 * Adds body classes to denote:
 * 1. Single or multiple authors.
 * 2. Active widgets in the sidebar to change the layout and spacing.
 * 3. When avatars are disabled in discussion settings.
 *
 * @since AmaTheme 1.0
 *
 * @param array $classes A list of existing body class values.
 * @return array The filtered body class list.
 */
function amatheme_body_class( $classes ) {
	if ( ! is_multi_author() )
		$classes[] = 'single-author';

	if ( is_active_sidebar( 'sidebar-2' ) && ! is_attachment() && ! is_404() )
		$classes[] = 'sidebar';

	if ( ! get_option( 'show_avatars' ) )
		$classes[] = 'no-avatars';

	return $classes;
}
add_filter( 'body_class', 'amatheme_body_class' );

/**
 * Adjusts content_width value for video post formats and attachment templates.
 *
 * @since AmaTheme 1.0
 *
 * @return void
 */
function amatheme_content_width() {
	global $content_width;

	if ( is_attachment() )
		$content_width = 724;
	elseif ( has_post_format( 'audio' ) )
		$content_width = 484;
}
add_action( 'template_redirect', 'amatheme_content_width' );

/**
 * Add postMessage support for site title and description for the Customizer.
 *
 * @since AmaTheme 1.0
 *
 * @param WP_Customize_Manager $wp_customize Customizer object.
 * @return void
 */
function amatheme_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
}
add_action( 'customize_register', 'amatheme_customize_register' );

/**
 * Binds JavaScript handlers to make Customizer preview reload changes
 * asynchronously.
 *
 * @since AmaTheme 1.0
 */
function amatheme_customize_preview_js() {
	wp_enqueue_script( 'amatheme-customizer', get_template_directory_uri() . '/js/theme-customizer.js', array( 'customize-preview' ), '20130226', true );
}
add_action( 'customize_preview_init', 'amatheme_customize_preview_js' );
